# Copyright (c) 2016, Patrick Uiterwijk <patrick@puiterwijk.org>
# All rights reserved.
#
# This file is part of Basset.
#
# Basset is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Basset is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Basset.  If not, see <http://www.gnu.org/licenses/>.

import dns.name
import dns.resolver

from basset.score.base import ScorePlugin


class MailExchangeScore(ScorePlugin):
    name = 'mailexchange'
    quick = False

    def _do_init(self):
        # Initialize
        self._evilsuperdomains = {}
        for option in self.config:
            if option.startswith('superdomain_'):
                key = option[len('superdomain_'):]
                self._evilsuperdomains[key] = self.config[option]

    def get_score(self, action, time, data):
        email = data['user']['email']

        scores = {}
        scores['mx'] = self.get_mx_score(email)

        return scores

    def get_mx_score(self, email):
        username, domain = email.split('@')
        answers = dns.resolver.query(domain, 'MX')
        score = 0
        for answer in answers:
            for evildomain in self._evilsuperdomains:
                dmn = dns.name.from_text(evildomain)
                if answer.exchange.is_subdomain(dmn):
                    score += int(self._evilsuperdomains[evildomain])
        return score
